```{include} ../README.md

```

```{toctree}
---
maxdepth: 1
---
why
registry
injection
future
reference
contributing
Code of Conduct <codeofconduct>
License <license>
Changelog <https://github.com/pauleveritt/hopscotch/releases>
```
